@@ -12,12 +12,17 @@ class ArinRest(object):
     ) -> None:
         self.api_key = api_key
 
-    def rpki(self, **kwargs):
-        connection = ArinRestConnection("rpki", self.api_key, **kwargs)
-        return Rpki(connection)
+    def rpki(self, private_key: str, **kwargs):
+        dev = kwargs.get("dev", False)
+
+        connection = ArinRestConnection("rpki", self.api_key, dev=dev)
+
+        return Rpki(connection, private_key=private_key)
 
     def irr(self, **kwargs):
-        self.connection = ArinRestConnection("irr", self.api_key, **kwargs)
+        dev = kwargs.get("dev", False)
+
+        self.connection = ArinRestConnection("irr", self.api_key, dev=dev)
         self.route = Route(self.connection)
         return self
 
